@@ -36,3 +36,10 @@ try:
     register_backend(fasttext.FastTextBackend)
 except ImportError:
     annif.logger.debug("fastText not available, not enabling fasttext backend")
+
+try:
+    from . import vw_multi
+    register_backend(vw_multi.VWMultiBackend)
+except ImportError:
+    annif.logger.debug(
+        "vowpalwabbit not available, not enabling vw_multi backend")
