@@ -1,8 +1,6 @@
 """Common functionality for backends."""
 
 import abc
-import os
-import os.path
 from annif import logger
 
 
@@ -20,14 +18,7 @@ class AnnifBackend(metaclass=abc.ABCMeta):
         backend type."""
         self.backend_id = backend_id
         self.params = params
-        self._datadir = datadir
-
-    def _get_datadir(self):
-        """return the path of the directory where this backend can store its
-        data files"""
-        if not os.path.exists(self._datadir):
-            os.makedirs(self._datadir)
-        return self._datadir
+        self.datadir = datadir
 
     def train(self, corpus, project):
         """train the model on the given document or subject corpus"""
@@ -42,7 +33,7 @@ class AnnifBackend(metaclass=abc.ABCMeta):
     def _analyze(self, text, project, params):
         """This method should implemented by backends. It implements
         the analyze functionality, with pre-processed parameters."""
-        pass
+        pass  # pragma: no cover
 
     def analyze(self, text, project, params=None):
         """Analyze some input text and return a list of subjects represented
@@ -63,3 +54,12 @@ class AnnifBackend(metaclass=abc.ABCMeta):
     def warning(self, message):
         """Log a warning message from this backend"""
         logger.warning("Backend {}: {}".format(self.backend_id, message))
+
+
+class AnnifLearningBackend(AnnifBackend):
+    """Base class for Annif backends that can perform online learning"""
+
+    @abc.abstractmethod
+    def learn(self, corpus, project):
+        """further train the model on the given document or subject corpus"""
+        pass  # pragma: no cover
