@@ -7,9 +7,10 @@ from annif.hit import AnalysisHit, ListAnalysisResult
 from annif.exception import NotInitializedException
 import fastText
 from . import backend
+from . import mixins
 
 
-class FastTextBackend(backend.AnnifBackend):
+class FastTextBackend(mixins.ChunkingBackend, backend.AnnifBackend):
     """fastText backend for Annif"""
 
     name = "fasttext"
@@ -40,7 +41,7 @@ class FastTextBackend(backend.AnnifBackend):
 
     def initialize(self):
         if self._model is None:
-            path = os.path.join(self._get_datadir(), self.MODEL_FILE)
+            path = os.path.join(self.datadir, self.MODEL_FILE)
             self.debug('loading fastText model from {}'.format(path))
             if os.path.exists(path):
                 self._model = fastText.load_model(path)
@@ -51,12 +52,12 @@ class FastTextBackend(backend.AnnifBackend):
                     'model {} not found'.format(path),
                     backend_id=self.backend_id)
 
-    @classmethod
-    def _id_to_label(cls, subject_id):
+    @staticmethod
+    def _id_to_label(subject_id):
         return "__label__{:d}".format(subject_id)
 
-    @classmethod
-    def _label_to_subject(cls, project, label):
+    @staticmethod
+    def _label_to_subject(project, label):
         labelnum = label.replace('__label__', '')
         subject_id = int(labelnum)
         return project.subjects[subject_id]
@@ -71,8 +72,8 @@ class FastTextBackend(backend.AnnifBackend):
                 else:
                     self.warning('no labels for document "{}"'.format(doc))
 
-    @classmethod
-    def _normalize_text(cls, project, text):
+    @staticmethod
+    def _normalize_text(project, text):
         return ' '.join(project.analyzer.tokenize_words(text))
 
     def _create_train_file(self, corpus, project):
@@ -88,14 +89,14 @@ class FastTextBackend(backend.AnnifBackend):
                                   for uri in doc.uris]
 
         annif.util.atomic_save(doc_subjects,
-                               self._get_datadir(),
+                               self.datadir,
                                self.TRAIN_FILE,
                                method=self._write_train_file)
 
     def _create_model(self):
         self.info('creating fastText model')
-        trainpath = os.path.join(self._get_datadir(), self.TRAIN_FILE)
-        modelpath = os.path.join(self._get_datadir(), self.MODEL_FILE)
+        trainpath = os.path.join(self.datadir, self.TRAIN_FILE)
+        modelpath = os.path.join(self.datadir, self.MODEL_FILE)
         params = {param: self.FASTTEXT_PARAMS[param](val)
                   for param, val in self.params.items()
                   if param in self.FASTTEXT_PARAMS}
@@ -106,9 +107,15 @@ class FastTextBackend(backend.AnnifBackend):
         self._create_train_file(corpus, project)
         self._create_model()
 
+    def _predict_chunks(self, chunktexts, project, limit):
+        return self._model.predict(list(
+            filter(None, [self._normalize_text(project, chunktext)
+                          for chunktext in chunktexts])), limit)
+
     def _analyze_chunks(self, chunktexts, project):
         limit = int(self.params['limit'])
-        chunklabels, chunkscores = self._model.predict(chunktexts, limit)
+        chunklabels, chunkscores = self._predict_chunks(
+            chunktexts, project, limit)
         label_scores = collections.defaultdict(float)
         for labels, scores in zip(chunklabels, chunkscores):
             for label, score in zip(labels, scores):
@@ -125,20 +132,3 @@ class FastTextBackend(backend.AnnifBackend):
                 label=subject[1],
                 score=score / len(chunktexts)))
         return ListAnalysisResult(results, project.subjects)
-
-    def _analyze(self, text, project, params):
-        self.initialize()
-        self.debug('Analyzing text "{}..." (len={})'.format(
-            text[:20], len(text)))
-        sentences = project.analyzer.tokenize_sentences(text)
-        self.debug('Found {} sentences'.format(len(sentences)))
-        chunksize = int(params['chunksize'])
-        chunktexts = []
-        for i in range(0, len(sentences), chunksize):
-            chunktext = ' '.join(sentences[i:i + chunksize])
-            normalized = self._normalize_text(project, chunktext)
-            if normalized != '':
-                chunktexts.append(normalized)
-        self.debug('Split sentences into {} chunks'.format(len(chunktexts)))
-
-        return self._analyze_chunks(chunktexts, project)
