@@ -13,6 +13,7 @@ import annif
 import annif.corpus
 import annif.eval
 import annif.project
+from annif.project import Access
 from annif.hit import HitFilter
 
 logger = annif.logger
@@ -25,7 +26,7 @@ def get_project(project_id):
     """
     Helper function to get a project by ID and bail out if it doesn't exist"""
     try:
-        return annif.project.get_project(project_id)
+        return annif.project.get_project(project_id, min_access=Access.hidden)
     except ValueError:
         click.echo(
             "No projects found with id \'{0}\'.".format(project_id),
@@ -79,13 +80,11 @@ def run_list_projects():
     List available projects.
     """
 
-    template = "{0: <15}{1: <30}{2: <15}"
-
+    template = "{0: <25}{1: <45}{2: <8}"
     header = template.format("Project ID", "Project Name", "Language")
     click.echo(header)
     click.echo("-" * len(header))
-
-    for proj in annif.project.get_projects().values():
+    for proj in annif.project.get_projects(min_access=Access.private).values():
         click.echo(template.format(proj.project_id, proj.name, proj.language))
 
 
@@ -97,12 +96,11 @@ def run_show_project(project_id):
     """
 
     proj = get_project(project_id)
-
     template = "{0:<20}{1}"
-
     click.echo(template.format('Project ID:', proj.project_id))
-    click.echo(template.format('Project Name:', proj.project_id))
+    click.echo(template.format('Project Name:', proj.name))
     click.echo(template.format('Language:', proj.language))
+    click.echo(template.format('Access:', proj.access.name))
 
 
 @cli.command('loadvoc')
@@ -136,6 +134,19 @@ def run_train(project_id, paths):
     proj.train(documents)
 
 
+@cli.command('learn')
+@click_log.simple_verbosity_option(logger)
+@click.argument('project_id')
+@click.argument('paths', type=click.Path(), nargs=-1)
+def run_learn(project_id, paths):
+    """
+    Further train an existing project on a collection of documents.
+    """
+    proj = get_project(project_id)
+    documents = open_documents(paths)
+    proj.learn(documents)
+
+
 @cli.command('analyze')
 @click_log.simple_verbosity_option(logger)
 @click.argument('project_id')
@@ -266,7 +277,11 @@ def run_optimize(project_id, paths, backend_param):
     best_params = {}
 
     template = "{:d}\t{:.02f}\t{:.04f}\t{:.04f}\t{:.04f}"
-    for params, filter_batch in filter_batches.items():
+    # Store the batches in a list that gets consumed along the way
+    # This way GC will have a chance to reclaim the memory
+    filter_batches = list(filter_batches.items())
+    while filter_batches:
+        params, filter_batch = filter_batches.pop(0)
         results = filter_batch[1].results(metrics='simple')
         for metric, score in results.items():
             if score >= best_scores[metric]:
