@@ -1,8 +1,9 @@
 """Annif corpus operations"""
 
 
-from .document import DocumentDirectory, DocumentFile
+from .document import DocumentDirectory, DocumentFile, DocumentList
 from .subject import Subject, SubjectDirectory, SubjectFileTSV
 from .subject import SubjectIndex, SubjectSet
 from .skos import SubjectFileSKOS
+from .types import Document
 from .combine import CombinedCorpus
