@@ -40,7 +40,7 @@ class DocumentDirectory(DocumentCorpus, DocumentToSubjectCorpusMixin):
             with open(docfilename, errors='replace') as docfile:
                 text = docfile.read()
             with open(keyfilename) as keyfile:
-                subjects = SubjectSet(keyfile.read())
+                subjects = SubjectSet.from_string(keyfile.read())
             yield Document(text=text, uris=subjects.subject_uris,
                            labels=subjects.subject_labels)
 
@@ -66,3 +66,15 @@ class DocumentFile(DocumentCorpus, DocumentToSubjectCorpusMixin):
                 subjects = [annif.util.cleanup_uri(uri)
                             for uri in uris.split()]
                 yield Document(text=text, uris=subjects, labels=[])
+
+
+class DocumentList(DocumentCorpus, DocumentToSubjectCorpusMixin):
+    """A document corpus based on a list of other iterable of Document
+    objects"""
+
+    def __init__(self, documents):
+        self._documents = documents
+
+    @property
+    def documents(self):
+        yield from self._documents
