@@ -2,6 +2,7 @@
 
 import collections
 import configparser
+import enum
 import os.path
 from sklearn.externals import joblib
 from sklearn.feature_extraction.text import TfidfVectorizer
@@ -13,13 +14,21 @@ import annif.hit
 import annif.backend
 import annif.util
 import annif.vocab
+from annif.datadir import DatadirMixin
 from annif.exception import AnnifException, ConfigurationException, \
-    NotInitializedException
+    NotInitializedException, NotSupportedException
 
 logger = annif.logger
 
 
-class AnnifProject:
+class Access(enum.IntEnum):
+    """Enumeration of access levels for projects"""
+    private = 1
+    hidden = 2
+    public = 3
+
+
+class AnnifProject(DatadirMixin):
     """Class representing the configuration of a single Annif project."""
 
     # defaults for uninitialized instances
@@ -29,22 +38,28 @@ class AnnifProject:
     _vectorizer = None
     initialized = False
 
+    # default values for configuration settings
+    DEFAULT_ACCESS = 'public'
+
     def __init__(self, project_id, config, datadir):
+        DatadirMixin.__init__(self, datadir, 'projects', project_id)
         self.project_id = project_id
         self.name = config['name']
         self.language = config['language']
         self.analyzer_spec = config.get('analyzer', None)
         self.vocab_id = config.get('vocab', None)
-        self._base_datadir = datadir
-        self._datadir = os.path.join(datadir, 'projects', self.project_id)
         self.config = config
+        self._base_datadir = datadir
+        self._init_access()
 
-    def _get_datadir(self):
-        """return the path of the directory where this project can store its
-        data files"""
-        if not os.path.exists(self._datadir):
-            os.makedirs(self._datadir)
-        return self._datadir
+    def _init_access(self):
+        access = self.config.get('access', self.DEFAULT_ACCESS)
+        try:
+            self.access = getattr(Access, access)
+        except AttributeError:
+            raise ConfigurationException(
+                "'{}' is not a valid access setting".format(access),
+                project_id=self.project_id)
 
     def _initialize_analyzer(self):
         analyzer = self.analyzer
@@ -115,9 +130,12 @@ class AnnifProject:
             try:
                 backend_class = annif.backend.get_backend(backend_id)
                 self._backend = backend_class(
-                    backend_id, params=self.config, datadir=self._datadir)
+                    backend_id, params=self.config, datadir=self.datadir)
             except ValueError:
-                logger.debug("Could not create backend %s", backend_id)
+                logger.warning(
+                    "Could not create backend %s, "
+                    "make sure you've installed optional dependencies",
+                    backend_id)
         return self._backend
 
     @property
@@ -137,7 +155,7 @@ class AnnifProject:
     @property
     def vectorizer(self):
         if self._vectorizer is None:
-            path = os.path.join(self._get_datadir(), 'vectorizer')
+            path = os.path.join(self.datadir, 'vectorizer')
             if os.path.exists(path):
                 logger.debug('loading vectorizer from %s', path)
                 self._vectorizer = joblib.load(path)
@@ -167,7 +185,7 @@ class AnnifProject:
         self._vectorizer.fit((subj.text for subj in subjectcorpus.subjects))
         annif.util.atomic_save(
             self._vectorizer,
-            self._get_datadir(),
+            self.datadir,
             'vectorizer',
             method=joblib.dump)
 
@@ -178,6 +196,18 @@ class AnnifProject:
         self._create_vectorizer(corpus)
         self.backend.train(corpus, project=self)
 
+    def learn(self, corpus):
+        """further train the project using documents from a metadata source"""
+
+        corpus.set_subject_index(self.subjects)
+        if isinstance(
+                self.backend,
+                annif.backend.backend.AnnifLearningBackend):
+            self.backend.learn(corpus, project=self)
+        else:
+            raise NotSupportedException("Learning not supported by backend",
+                                        project_id=self.project_id)
+
     def dump(self):
         """return this project as a dict"""
         return {'project_id': self.project_id,
@@ -219,14 +249,20 @@ def initialize_projects(app):
         projects_file, datadir, init_projects)
 
 
-def get_projects():
-    """return the available projects as a dict of project_id -> AnnifProject"""
-    return current_app.annif_projects
+def get_projects(min_access=Access.private):
+    """Return the available projects as a dict of project_id ->
+    AnnifProject. The min_access parameter may be used to set the minimum
+    access level required for the returned projects."""
+
+    projects = [(project_id, project)
+                for project_id, project in current_app.annif_projects.items()
+                if project.access >= min_access]
+    return collections.OrderedDict(projects)
 
 
-def get_project(project_id):
+def get_project(project_id, min_access=Access.private):
     """return the definition of a single Project by project_id"""
-    projects = get_projects()
+    projects = get_projects(min_access)
     try:
         return projects[project_id]
     except KeyError:
