@@ -4,7 +4,16 @@ import os
 import pytest
 import annif.project
 import annif.backend.dummy
-from annif.exception import ConfigurationException
+from annif.exception import ConfigurationException, NotSupportedException
+from annif.project import Access
+
+
+def test_create_project_wrong_access(app):
+    with pytest.raises(ConfigurationException):
+        project = annif.project.AnnifProject(
+            'example',
+            {'name': 'Example', 'language': 'en', 'access': 'invalid'},
+            '.')
 
 
 def test_get_project_en(app):
@@ -14,6 +23,7 @@ def test_get_project_en(app):
     assert project.language == 'en'
     assert project.analyzer.name == 'snowball'
     assert project.analyzer.param == 'english'
+    assert project.access == Access.hidden
     assert isinstance(project.backend, annif.backend.dummy.DummyBackend)
 
 
@@ -24,6 +34,18 @@ def test_get_project_fi(app):
     assert project.language == 'fi'
     assert project.analyzer.name == 'snowball'
     assert project.analyzer.param == 'finnish'
+    assert project.access == Access.public
+    assert isinstance(project.backend, annif.backend.dummy.DummyBackend)
+
+
+def test_get_project_dummydummy(app):
+    with app.app_context():
+        project = annif.project.get_project('dummydummy')
+    assert project.project_id == 'dummydummy'
+    assert project.language == 'en'
+    assert project.analyzer.name == 'snowball'
+    assert project.analyzer.param == 'english'
+    assert project.access == Access.private
     assert isinstance(project.backend, annif.backend.dummy.DummyBackend)
 
 
@@ -70,6 +92,36 @@ def test_project_train_tfidf(app, document_corpus, testdatadir):
     assert testdatadir.join('projects/tfidf-fi/tfidf-index').size() > 0
 
 
+def test_project_learn(app, tmpdir):
+    tmpdir.join('doc1.txt').write('doc1')
+    tmpdir.join('doc1.tsv').write('<http://example.org/key1>\tkey1')
+    tmpdir.join('doc2.txt').write('doc2')
+    tmpdir.join('doc2.tsv').write('<http://example.org/key2>\tkey2')
+    docdir = annif.corpus.DocumentDirectory(str(tmpdir))
+
+    with app.app_context():
+        project = annif.project.get_project('dummy-fi')
+        project.learn(docdir)
+        result = project.analyze('this is some text')
+        assert len(result) == 1
+        assert result[0].uri == 'http://example.org/key1'
+        assert result[0].label == 'key1'
+        assert result[0].score == 1.0
+
+
+def test_project_learn_not_supported(app, tmpdir):
+    tmpdir.join('doc1.txt').write('doc1')
+    tmpdir.join('doc1.tsv').write('<http://example.org/key1>\tkey1')
+    tmpdir.join('doc2.txt').write('doc2')
+    tmpdir.join('doc2.tsv').write('<http://example.org/key2>\tkey2')
+    docdir = annif.corpus.DocumentDirectory(str(tmpdir))
+
+    with app.app_context():
+        project = annif.project.get_project('tfidf-fi')
+        with pytest.raises(NotSupportedException):
+            project.learn(docdir)
+
+
 def test_project_load_vocabulary_fasttext(app, vocabulary, testdatadir):
     pytest.importorskip("annif.backend.fasttext")
     with app.app_context():
